==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_external/l10n/el.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Η λήψη των τεκμηρίων αιτήματος απέτυχε. Βεβαιώστε ότι το κλειδί εφαρμογής και το μυστικό είναι ορθά.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Η λήψη των τεκμηρίων πρόσβασης απέτυχε. Βεβαιώστε ότι το κλειδί εφαρμογής και το μυστικό είναι ορθά.",
    "Please provide a valid app key and secret." : "Παρακαλούμε δώστε έγκυρο κλειδί εφαρμογής και μυστικό.",
    "Step 1 failed. Exception: %s" : "Το βήμα 1 απέτυχε. Εξαίρεση: %s",
    "Step 2 failed. Exception: %s" : "Το βήμα 2 απέτυχε. Εξαίρεση: %s",
    "External storage" : "Εξωτερική αποθήκευση",
    "Dropbox App Configuration" : "Ρυθμίσεις εφαρμογής Dropbox",
    "Google Drive App Configuration" : "Ρυθμίσεις εφαρμογής Google Drive",
    "Personal" : "Προσωπικά",
    "System" : "Σύστημα",
    "Grant access" : "Παροχή πρόσβασης",
    "Error configuring OAuth1" : "Σφάλμα ρύθμισης του OAuth1",
    "Error configuring OAuth2" : "Σφάλμα ρύθμισης του OAuth2",
    "Generate keys" : "Δημιουργία κλειδιών",
    "Error generating key pair" : "Σφάλμα κατά τη δημιουργία ζεύγους κλειδιών",
    "All users. Type to select user or group." : "Όλοι οι χρήστες. Πληκτρολογήστε για να επιλέξετε χρήστη ή ομάδα.",
    "(group)" : "(ομάδα)",
    "Saved" : "Αποθηκεύτηκαν",
    "Saving..." : "Γίνεται αποθήκευση...",
    "Save" : "Αποθήκευση",
    "Empty response from the server" : "Κενή απάντηση από τον διακομιστή",
    "Couldn't access. Please logout and login to activate this mount point" : "Αδυναμία πρόσβασης. Παρακαλώ εξέλθετε και εισέλθετε ξανά ώστε να ενεργοποιήσετε το σημείο προσάρτησης",
    "There was an error with message: " : "Υπήρξε σφάλμα στο μήνυμα:",
    "External mount error" : "Σφάλμα εξωτερικής προσάρτησης",
    "external-storage" : "εξωτερική-αποθήκευση",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Credentials saved" : "Τα διαπιστευτήρια αποθηκεύτηκαν",
    "Credentials saving failed" : "Αποτυχία αποθήκευσης διαπιστευτηρίων",
    "Storage with id \"%i\" not found" : "Αποθήκευση με id \"%i\" δεν βρέθηκε",
    "Invalid backend or authentication mechanism class" : "Μη έγκυρη κλάση συστήματος ή μηχανισμού πιστοποίησης",
    "Invalid mount point" : "Μη έγκυρο σημείο ανάρτησης",
    "Objectstore forbidden" : "Απαγορευμένο objectstore",
    "Invalid storage backend \"%s\"" : "Μή έγκυρο σύστημα υποστήριξης αποθήκευσης  \"%s\"",
    "Not permitted to use backend \"%s\"" : "Μη επιτρεπόμενο σύστημα υποστήριξης \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Μη επιτρεπόμενος μηχανισμός πιστοποίησης \"%s\"",
    "Unsatisfied backend parameters" : "Ελλιπείς παράμετροι συστήματος",
    "Unsatisfied authentication mechanism parameters" : "Ελλιπείς παράμετροι μηχανισμού πιστοποίησης",
    "Insufficient data: %s" : "Μη επαρκή δεδομένα: %s",
    "%s" : "%s",
    "Access key" : "Κλειδί πρόσβασης",
    "Secret key" : "Μυστικό κλειδί",
    "Builtin" : "Builtin",
    "None" : "Τίποτα",
    "OAuth1" : "OAuth1",
    "App key" : "Κλειδί εφαρμογής",
    "App secret" : "Μυστικό εφαρμογής",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID πελάτη",
    "Client secret" : "Μυστικό πελάτη",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Όνομα \"ένοικου\"",
    "Identity endpoint URL" : "URL τελικού σημείου ταυτοποίησης",
    "Rackspace" : "Rackspace",
    "API key" : "Κλειδί Google API",
    "Username and password" : "Όνομα χρήστη και κωδικός πρόσβασης",
    "RSA public key" : "Δημόσιο κλειδί RSA",
    "Public key" : "Δημόσιο κλειδί",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Κάδος",
    "Hostname" : "Όνομα Υπολογιστή",
    "Port" : "Θύρα",
    "Region" : "Περιοχή",
    "Enable SSL" : "Ενεργοποίηση SSL",
    "Enable Path Style" : "Ενεργοποίηση μορφής διαδρομής",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Απομακρυσμένος υποφάκελος",
    "Secure https://" : "Ασφαλής σύνδεση https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Διακομιστής",
    "Secure ftps://" : "Ασφαλής ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Τοπικός",
    "Location" : "Τοποθεσία",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP με σύνδεση με κρυφό κλειδί",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Διαμοιράστε",
    "Domain" : "Τομέας",
    "SMB / CIFS using OC login" : "SMB / CIFS χρησιμοποιώντας λογαριασμό OC",
    "Username as share" : "Όνομα χρήστη ως διαμοιραζόμενος φάκελος",
    "OpenStack Object Storage" : "Αποθήκη αντικειμένων OpenStack",
    "Service name" : "Όνομα υπηρεσίας",
    "Request timeout (seconds)" : "Χρονικό όριο αιτήματος (δευτερόλεπτα)",
    "External storages" : "Εξωτερική αποθήκευση",
    "No external storage configured" : "Δεν έχει ρυθμιστεί κανένα εξωτερικό μέσο αποθήκευσης",
    "You can add external storages in the personal settings" : "Μπορείτε να προσθέσετε εξωτερικά μέσα αποθήκευσης στις προσωπικές ρυθμίσεις",
    "Name" : "Όνομα",
    "Storage type" : "Τύπος αποθηκευτικού χώρου",
    "Scope" : "Εύρος",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "Enable previews" : "Ενεργοποίηση προεπισκοπήσεων",
    "Check for changes" : "Έλεγχος για αλλαγές",
    "Never" : "Ποτέ",
    "Once every direct access" : "Σε κάθε απευθείας πρόσβαση",
    "Folder name" : "Όνομα φακέλου",
    "Authentication" : "Πιστοποίηση",
    "Configuration" : "Ρυθμίσεις",
    "Available for" : "Διαθέσιμο για",
    "Add storage" : "Προσθηκη αποθηκευσης",
    "Advanced settings" : "Ρυθμίσεις για προχωρημένους",
    "Delete" : "Διαγραφή",
    "Allow users to mount external storage" : "Να επιτρέπεται στους χρήστες η σύνδεση εξωτερικού χώρου",
    "Allow users to mount the following external storage" : "Χορήγηση άδειας στους χρήστες να συνδέσουν τα παρακάτω εξωτερικά μέσα αποθήκευσης",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Αδυναμία λήψης πληροφορίας από τον διακομιστή nextcloud: {code} {type}",
    "ownCloud" : "ownCloud",
    "<b>Note:</b> " : "<b>Σημείωση:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Σημείωση:</b> Η υποστήριξη cURL στην PHP δεν είναι ενεργοποιημένη ή εγκατεστημένη. Η προσάρτηση του %s δεν είναι δυνατή. Παρακαλώ ζητήστε από τον διαχειριστή συστημάτων σας να την εγκαταστήσει.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Σημείωση:</b> Η υποστήριξη FTP στην PHP δεν είναι ενεργοποιημένη ή εγκατεστημένη. Δεν είναι δυνατή η προσάρτηση του %s. Παρακαλώ ζητήστε από τον διαχειριστή συστημάτων σας να την εγκαταστήσει.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Σημείωση:</b> Η επέκταση \"%s\" δεν είναι εγκατεστημένη. Δεν είναι δυνατή η προσάρτηση %s. Παρακαλώ ζητήστε από τον διαχειριστή συστημάτων σας να την εγκαταστήσει.",
    "External Storage" : "Εξωτερικό Αποθηκευτικό Μέσο"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/files_external/l10n/el.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Εξωτερική αποθήκευση",
    "Personal" : "Προσωπικά",
    "System" : "Σύστημα",
    "Grant access" : "Παροχή πρόσβασης",
    "Error configuring OAuth1" : "Σφάλμα ρύθμισης του OAuth1",
    "Please provide a valid app key and secret." : "Παρακαλούμε δώστε έγκυρο κλειδί εφαρμογής και μυστικό.",
    "Error configuring OAuth2" : "Σφάλμα ρύθμισης του OAuth2",
    "Generate keys" : "Δημιουργία κλειδιών",
    "Error generating key pair" : "Σφάλμα κατά τη δημιουργία ζεύγους κλειδιών",
    "All users. Type to select user or group." : "Όλοι οι χρήστες. Πληκτρολογήστε για να επιλέξετε χρήστη ή ομάδα.",
    "(group)" : "(ομάδα)",
    "Compatibility with Mac NFD encoding (slow)" : "Συμβατότητα με Mac NFD κωδικόποιηση (αργό) ",
    "Admin defined" : "Ορίσθηκε διαχειριστής ",
    "Saved" : "Αποθηκεύτηκαν",
    "Saving..." : "Γίνεται αποθήκευση...",
    "Save" : "Αποθήκευση",
    "Empty response from the server" : "Κενή απάντηση από τον διακομιστή",
    "Couldn't access. Please log out and in again to activate this mount point" : "Αδυναμία πρόσβασης. Παρακαλούμε αποσυνδεθείτε και συνδεθείτε ξανά για ενεργοποίηση του σημείου προσάρτησης",
    "Couldn't get the information from the remote server: {code} {type}" : "Δεν μπορέσαμε να πάρουμε πληροφορίες απο τον απομακρυσμένο εξυπηρετητή: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Δεν μπορέσαμε να πάρουμε την λίστα εξωτερικών σημείων προσάρτησης: {type}",
    "There was an error with message: " : "Υπήρξε σφάλμα στο μήνυμα:",
    "External mount error" : "Σφάλμα εξωτερικής προσάρτησης",
    "external-storage" : "εξωτερική-αποθήκευση",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Αδυναμία λήψης της λίστας των σημείων προσάρτησης δικτύων Windows: Κενή απάντηση από τον διακομιστή",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Μερικά από τα διαμορφωμένα εξωτερικά σημεία προσάρτησης δεν είναι συνδεδεμένα. Παρακαλούμε κάντε κλικ στο κόκκινο βέλος(οι) για περισσότερες πληροφορίες",
    "Please enter the credentials for the {mount} mount" : "Παρακαλούμε βάλτε τα διαπιστευτήρια  για την  {mount} προσάρτηση",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Credentials saved" : "Τα διαπιστευτήρια αποθηκεύτηκαν",
    "Credentials saving failed" : "Αποτυχία αποθήκευσης διαπιστευτηρίων",
    "Credentials required" : "Απαιτούνται διαπιστευτήρια ",
    "Storage with ID \"%d\" not found" : "Αποθηκευτικός χώρος με ID \"%d\" δεν βρέθηκε ",
    "Invalid backend or authentication mechanism class" : "Μη έγκυρη κλάση συστήματος ή μηχανισμού πιστοποίησης",
    "Invalid mount point" : "Μη έγκυρο σημείο ανάρτησης",
    "Objectstore forbidden" : "Απαγορευμένο objectstore",
    "Invalid storage backend \"%s\"" : "Μή έγκυρο σύστημα υποστήριξης αποθήκευσης  \"%s\"",
    "Not permitted to use backend \"%s\"" : "Μη επιτρεπόμενο σύστημα υποστήριξης \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Μη επιτρεπόμενος μηχανισμός πιστοποίησης \"%s\"",
    "Unsatisfied backend parameters" : "Ελλιπείς παράμετροι συστήματος",
    "Unsatisfied authentication mechanism parameters" : "Ελλιπείς παράμετροι μηχανισμού πιστοποίησης",
    "Insufficient data: %s" : "Μη επαρκή δεδομένα: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Αποθηκευτικός χώρος με ID \"%d\" δεν είναι επεξεργάσιμος από τον χρήστη ",
    "Access key" : "Κλειδί πρόσβασης",
    "Secret key" : "Μυστικό κλειδί",
    "Builtin" : "Builtin",
    "None" : "Τίποτα",
    "OAuth1" : "OAuth1",
    "App key" : "Κλειδί εφαρμογής",
    "App secret" : "Μυστικό εφαρμογής",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID πελάτη",
    "Client secret" : "Μυστικό πελάτη",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Όνομα \"ένοικου\"",
    "Identity endpoint URL" : "URL τελικού σημείου ταυτοποίησης",
    "Rackspace" : "Rackspace",
    "API key" : "Κλειδί API",
    "Global credentials" : "Παγκόσμια διαπιστευτήρια",
    "Log-in credentials, save in database" : "Διαπιστευτήρια εισόδου, αποθηκεύστε στην βάση δεδομέων",
    "Username and password" : "Όνομα χρήστη και κωδικός πρόσβασης",
    "Log-in credentials, save in session" : "Διαπιστευτήρια εισόδου, αποθηκεύστε στην συνεδρία ",
    "User entered, store in database" : "Χρήστης εισήχθη, τοποθετήστε στην βάση δεδομένων",
    "RSA public key" : "Δημόσιο κλειδί RSA",
    "Public key" : "Δημόσιο κλειδί",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Κάδος",
    "Hostname" : "Όνομα Υπολογιστή",
    "Port" : "Θύρα",
    "Region" : "Περιοχή",
    "Enable SSL" : "Ενεργοποίηση SSL",
    "Enable Path Style" : "Ενεργοποίηση μορφής διαδρομής",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Απομακρυσμένος υποφάκελος",
    "Secure https://" : "Ασφαλής σύνδεση https://",
    "FTP" : "FTP",
    "Host" : "Διακομιστής",
    "Secure ftps://" : "Ασφαλής ftps://",
    "Local" : "Τοπικός",
    "Location" : "Τοποθεσία",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP με σύνδεση με κρυφό κλειδί",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Διαμοιράστε",
    "Domain" : "Τομέας",
    "SMB / CIFS using OC login" : "SMB / CIFS χρησιμοποιώντας λογαριασμό OC",
    "Username as share" : "Όνομα χρήστη ως διαμοιραζόμενος φάκελος",
    "OpenStack Object Storage" : "Αποθήκη αντικειμένων OpenStack",
    "Service name" : "Όνομα υπηρεσίας",
    "Request timeout (seconds)" : "Χρονικό όριο αιτήματος (δευτερόλεπτα)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Η cURL υποστήριξη στην PHP δεν είναι ενεργοποιημένη. Η προσάρτηση του %s δεν είναι δυνατή. Παρακαλούμε ζητήστε από τον διαχειριστή του συστήματός σας να το εγκαταστήσει. ",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Η FTP υποστήριξη στην PHP δεν είναι ενεργοποιημένη ή εγκατεστημένη. Η προσάρτηση του %s δεν είναι δυνατή. Παρακαλούμε ζητήστε τον διαχειριστή του συστήματός σας να το εγκατασταστήσει. ",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" δεν είναι εγκατεστημένο. Η προσάρτηση του %s δεν είναι δυνατή. Παρακαλούμε ζητήστε τον διαχειριστή του συστήματός σας να το εγκαταστήσει. ",
    "No external storage configured" : "Δεν έχει ρυθμιστεί κανένα εξωτερικό μέσο αποθήκευσης",
    "You can add external storages in the personal settings" : "Μπορείτε να προσθέσετε εξωτερικά μέσα αποθήκευσης στις προσωπικές ρυθμίσεις",
    "Name" : "Όνομα",
    "Storage type" : "Τύπος αποθηκευτικού χώρου",
    "Scope" : "Εύρος",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "Enable previews" : "Ενεργοποίηση προεπισκοπήσεων",
    "Enable sharing" : "Ενεργοποίηση διαμοιρασμού",
    "Check for changes" : "Έλεγχος για αλλαγές",
    "Never" : "Ποτέ",
    "Once every direct access" : "Σε κάθε απευθείας πρόσβαση",
    "Folder name" : "Όνομα φακέλου",
    "External storage" : "Εξωτερική αποθήκευση",
    "Authentication" : "Πιστοποίηση",
    "Configuration" : "Ρυθμίσεις",
    "Available for" : "Διαθέσιμο για",
    "Add storage" : "Προσθηκη αποθηκευσης",
    "Advanced settings" : "Ρυθμίσεις για προχωρημένους",
    "Delete" : "Διαγραφή",
    "Allow users to mount external storage" : "Να επιτρέπεται στους χρήστες η σύνδεση εξωτερικού χώρου",
    "Allow users to mount the following external storage" : "Χορήγηση άδειας στους χρήστες να συνδέσουν τα παρακάτω εξωτερικά μέσα αποθήκευσης",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Η λήψη των τεκμηρίων αιτήματος απέτυχε. Βεβαιώστε ότι το κλειδί εφαρμογής και το μυστικό είναι ορθά.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Η λήψη των τεκμηρίων πρόσβασης απέτυχε. Βεβαιώστε ότι το κλειδί εφαρμογής και το μυστικό είναι ορθά.",
    "Step 1 failed. Exception: %s" : "Το βήμα 1 απέτυχε. Εξαίρεση: %s",
    "Step 2 failed. Exception: %s" : "Το βήμα 2 απέτυχε. Εξαίρεση: %s",
    "Dropbox App Configuration" : "Ρυθμίσεις εφαρμογής Dropbox",
    "Google Drive App Configuration" : "Ρυθμίσεις εφαρμογής Google Drive",
    "Storage with id \"%i\" not found" : "Αποθήκευση με id \"%i\" δεν βρέθηκε",
    "Storage with id \"%i\" is not user editable" : "Αποθηκευτικός χώρος με ID \"%i\" δεν είναι επεξεργάσιμος από τον χρήστη ",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=2; plural=(n != 1);");
